'use client';
import React, { Fragment, useCallback, useEffect, useState } from 'react';
import { Collapsible as CollapsibleElement } from '../../elements/Collapsible/index.js';
import { ErrorPill } from '../../elements/ErrorPill/index.js';
import { useFieldProps } from '../../forms/FieldPropsProvider/index.js';
import { RenderFields } from '../../forms/RenderFields/index.js';
import { RowLabel } from '../../forms/RowLabel/index.js';
import { WatchChildErrors } from '../../forms/WatchChildErrors/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { useDocumentInfo } from '../../providers/DocumentInfo/index.js';
import { usePreferences } from '../../providers/Preferences/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { fieldBaseClass } from '../shared/index.js';
const baseClass = 'collapsible-field';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
const CollapsibleField = (props)=>{
    const { CustomDescription, CustomLabel, className, descriptionProps, fieldMap, initCollapsed = false, labelProps, path: pathFromProps, readOnly: readOnlyFromProps } = props;
    const { indexPath, path: pathFromContext, readOnly: readOnlyFromContext, schemaPath, siblingPermissions } = useFieldProps();
    const path = pathFromContext || pathFromProps;
    const { i18n } = useTranslation();
    const { getPreference, setPreference } = usePreferences();
    const { preferencesKey } = useDocumentInfo();
    const [collapsedOnMount, setCollapsedOnMount] = useState();
    const fieldPreferencesKey = `collapsible-${indexPath.replace(/\./g, '__')}`;
    const [errorCount, setErrorCount] = useState(0);
    const fieldHasErrors = errorCount > 0;
    const onToggle = useCallback(async (newCollapsedState)=>{
        const existingPreferences = await getPreference(preferencesKey);
        void setPreference(preferencesKey, {
            ...existingPreferences,
            ...path ? {
                fields: {
                    ...existingPreferences?.fields || {},
                    [path]: {
                        ...existingPreferences?.fields?.[path],
                        collapsed: newCollapsedState
                    }
                }
            } : {
                fields: {
                    ...existingPreferences?.fields || {},
                    [fieldPreferencesKey]: {
                        ...existingPreferences?.fields?.[fieldPreferencesKey],
                        collapsed: newCollapsedState
                    }
                }
            }
        });
    }, [
        preferencesKey,
        fieldPreferencesKey,
        getPreference,
        setPreference,
        path
    ]);
    useEffect(()=>{
        const fetchInitialState = async ()=>{
            const preferences = await getPreference(preferencesKey);
            if (preferences) {
                const initCollapsedFromPref = path ? preferences?.fields?.[path]?.collapsed : preferences?.fields?.[fieldPreferencesKey]?.collapsed;
                setCollapsedOnMount(Boolean(initCollapsedFromPref));
            } else {
                setCollapsedOnMount(typeof initCollapsed === 'boolean' ? initCollapsed : false);
            }
        };
        void fetchInitialState();
    }, [
        getPreference,
        preferencesKey,
        fieldPreferencesKey,
        initCollapsed,
        path
    ]);
    if (typeof collapsedOnMount !== 'boolean') return null;
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    return /*#__PURE__*/ React.createElement(Fragment, null, /*#__PURE__*/ React.createElement(WatchChildErrors, {
        fieldMap: fieldMap,
        path: path,
        setErrorCount: setErrorCount
    }), /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            className,
            fieldHasErrors ? `${baseClass}--has-error` : `${baseClass}--has-no-error`
        ].filter(Boolean).join(' '),
        id: `field-${fieldPreferencesKey}${path ? `-${path.replace(/\./g, '__')}` : ''}`
    }, /*#__PURE__*/ React.createElement(CollapsibleElement, {
        className: `${baseClass}__collapsible`,
        collapsibleStyle: fieldHasErrors ? 'error' : 'default',
        header: /*#__PURE__*/ React.createElement("div", {
            className: `${baseClass}__row-label-wrap`
        }, /*#__PURE__*/ React.createElement(RowLabel, {
            RowLabelComponent: CustomLabel,
            i18n: i18n,
            path: path,
            rowLabel: labelProps.label
        }), fieldHasErrors && /*#__PURE__*/ React.createElement(ErrorPill, {
            count: errorCount,
            i18n: i18n,
            withMessage: true
        })),
        initCollapsed: collapsedOnMount,
        onToggle: onToggle
    }, /*#__PURE__*/ React.createElement(RenderFields, {
        fieldMap: fieldMap,
        forceRender: true,
        indexPath: indexPath,
        margins: "small",
        path: path,
        permissions: siblingPermissions,
        readOnly: readOnly,
        schemaPath: schemaPath
    })), /*#__PURE__*/ React.createElement(FieldDescription, {
        CustomDescription: CustomDescription,
        ...descriptionProps || {}
    })));
};
export const Collapsible = withCondition(CollapsibleField);

//# sourceMappingURL=index.js.map