/* eslint-disable react/destructuring-assignment */ 'use client';
import { getTranslation } from '@payloadcms/translations';
import React, { useCallback } from 'react';
import { DatePickerField } from '../../elements/DatePicker/index.js';
import { FieldLabel } from '../../forms/FieldLabel/index.js';
import { useField } from '../../forms/useField/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { fieldBaseClass } from '../shared/index.js';
const baseClass = 'date-time-field';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
import { FieldError } from '@payloadcms/ui/forms/FieldError';
import { useFieldProps } from '@payloadcms/ui/forms/FieldPropsProvider';
import { withCondition } from '../../forms/withCondition/index.js';
const DateTimeField = (props)=>{
    const { name, AfterInput, BeforeInput, CustomDescription, CustomError, CustomLabel, className, date: datePickerProps, descriptionProps, errorProps, label, labelProps, path: pathFromProps, placeholder, readOnly: readOnlyFromProps, required, style, validate, width } = props;
    const { i18n } = useTranslation();
    const memoizedValidate = useCallback((value, options)=>{
        if (typeof validate === 'function') {
            return validate(value, {
                ...options,
                required
            });
        }
    }, [
        validate,
        required
    ]);
    const { path: pathFromContext, readOnly: readOnlyFromContext } = useFieldProps();
    const { path, setValue, showError, value } = useField({
        path: pathFromContext || pathFromProps || name,
        validate: memoizedValidate
    });
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            className,
            showError && `${baseClass}--has-error`,
            readOnly && 'read-only'
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement("div", {
        className: `${baseClass}__error-wrap`
    }, /*#__PURE__*/ React.createElement(FieldError, {
        CustomError: CustomError,
        path: path,
        ...errorProps || {}
    })), /*#__PURE__*/ React.createElement(FieldLabel, {
        CustomLabel: CustomLabel,
        label: label,
        required: required,
        ...labelProps || {}
    }), /*#__PURE__*/ React.createElement("div", {
        className: `${baseClass}__input-wrapper`,
        id: `field-${path.replace(/\./g, '__')}`
    }, BeforeInput, /*#__PURE__*/ React.createElement(DatePickerField, {
        ...datePickerProps,
        onChange: (incomingDate)=>{
            if (!readOnly) setValue(incomingDate?.toISOString() || null);
        },
        placeholder: getTranslation(placeholder, i18n),
        readOnly: readOnly,
        value: value
    }), AfterInput), CustomDescription !== undefined ? CustomDescription : /*#__PURE__*/ React.createElement(FieldDescription, descriptionProps || {}));
};
export const DateTime = withCondition(DateTimeField);

//# sourceMappingURL=index.js.map