'use client';
import { getTranslation } from '@payloadcms/translations';
import { FieldDescription } from '@payloadcms/ui/forms/FieldDescription';
import React, { Fragment } from 'react';
import { useCollapsible } from '../../elements/Collapsible/provider.js';
import { ErrorPill } from '../../elements/ErrorPill/index.js';
import { useFieldProps } from '../../forms/FieldPropsProvider/index.js';
import { useFormSubmitted } from '../../forms/Form/context.js';
import { RenderFields } from '../../forms/RenderFields/index.js';
import { useField } from '../../forms/useField/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { useRow } from '../Row/provider.js';
import { useTabs } from '../Tabs/provider.js';
import { fieldBaseClass } from '../shared/index.js';
import { GroupProvider, useGroup } from './provider.js';
const baseClass = 'group-field';
const GroupField = (props)=>{
    const { CustomDescription, CustomLabel, className, descriptionProps, fieldMap, hideGutter, labelProps, readOnly: readOnlyFromProps, style, width } = props;
    const { path, permissions, readOnly: readOnlyFromContext, schemaPath } = useFieldProps();
    const { i18n } = useTranslation();
    const { isWithinCollapsible } = useCollapsible();
    const isWithinGroup = useGroup();
    const isWithinRow = useRow();
    const isWithinTab = useTabs();
    const { errorPaths } = useField({
        path
    });
    const submitted = useFormSubmitted();
    const errorCount = errorPaths.length;
    const fieldHasErrors = submitted && errorCount > 0;
    const readOnly = readOnlyFromProps || readOnlyFromContext;
    const isTopLevel = !(isWithinCollapsible || isWithinGroup || isWithinRow);
    return /*#__PURE__*/ React.createElement(Fragment, null, /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            baseClass,
            isTopLevel && `${baseClass}--top-level`,
            isWithinCollapsible && `${baseClass}--within-collapsible`,
            isWithinGroup && `${baseClass}--within-group`,
            isWithinRow && `${baseClass}--within-row`,
            isWithinTab && `${baseClass}--within-tab`,
            !hideGutter && isWithinGroup && `${baseClass}--gutter`,
            fieldHasErrors && `${baseClass}--has-error`,
            className
        ].filter(Boolean).join(' '),
        id: `field-${path?.replace(/\./g, '__')}`,
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement(GroupProvider, null, /*#__PURE__*/ React.createElement("div", {
        className: `${baseClass}__wrap`
    }, /*#__PURE__*/ React.createElement("div", {
        className: `${baseClass}__header`
    }, (CustomLabel || CustomDescription || labelProps?.label) && /*#__PURE__*/ React.createElement("header", null, CustomLabel !== undefined ? CustomLabel : labelProps?.label ? /*#__PURE__*/ React.createElement("h3", {
        className: `${baseClass}__title`
    }, getTranslation(labelProps.label, i18n)) : null, CustomDescription !== undefined ? CustomDescription : /*#__PURE__*/ React.createElement(FieldDescription, descriptionProps || {})), fieldHasErrors && /*#__PURE__*/ React.createElement(ErrorPill, {
        count: errorCount,
        i18n: i18n,
        withMessage: true
    })), /*#__PURE__*/ React.createElement(RenderFields, {
        fieldMap: fieldMap,
        margins: "small",
        path: path,
        permissions: permissions?.fields,
        readOnly: readOnly,
        schemaPath: schemaPath
    })))));
};
export { GroupProvider, useGroup };
export const Group = withCondition(GroupField);

//# sourceMappingURL=index.js.map